Tutorial
========

.. toctree::
   :hidden:
   :titlesonly:

   01_first_LBM_for_transport<./notebooks/01_first_LBM_for_transport>
   02_first_LBM_for_waves<./notebooks/02_first_LBM_for_waves>
   03_heat_1D<./notebooks/03_heat_1D>
   04_heat_2D<./notebooks/04_heat_2D>
   05_Poiseuille<./notebooks/05_Poiseuille>
   06_Lid_driven_cavity<./notebooks/06_Lid_driven_cavity>
   07_Von_Karman_vortex_street<./notebooks/07_Von_Karman_vortex_street>
   08_advection_reaction<./notebooks/08_advection_reaction>

:download:`get the notebook<./notebooks/01_first_LBM_for_transport.ipynb>`


:doc:`./notebooks/01_first_LBM_for_transport`

In this tutorial, we will show how to implement from scratch a very basic lattice Boltzmann scheme: the :math:`D_1Q_2` for the advection equation and for Burger's equation.

:download:`get the notebook<./notebooks/02_first_LBM_for_waves.ipynb>`


:doc:`./notebooks/02_first_LBM_for_waves`

In this tutorial, we will show how to implement from scratch a very basic lattice Boltzmann scheme: the :math:`D_1Q_3` for the waves equation.

:download:`get the notebook<./notebooks/03_heat_1D.ipynb>`


:doc:`./notebooks/03_heat_1D`

In this tutorial, we present the :math:`D_1Q_3` to solve the heat equation in 1D by using pylbm.

:download:`get the notebook<./notebooks/04_heat_2D.ipynb>`


:doc:`./notebooks/04_heat_2D`

In this tutorial, we present the :math:`D_2Q_5` to solve the heat equation in 2D by using pylbm.

:download:`get the notebook<./notebooks/05_Poiseuille.ipynb>`


:doc:`./notebooks/05_Poiseuille`

In this tutorial, we present the :math:`D_2Q_9` for Navier-Stokes equation to solve the Poiseuille flow in 2D by using pylbm.

:download:`get the notebook<./notebooks/06_Lid_driven_cavity.ipynb>`


:doc:`./notebooks/06_Lid_driven_cavity`

In this tutorial, we present the :math:`D_2Q_9` for Navier-Stokes equation
to solve the lid driven cavity in 2D and the :math:`D3Q15` in 3D
by using pylbm.

:download:`get the notebook<./notebooks/07_Von_Karman_vortex_street.ipynb>`


:doc:`./notebooks/07_Von_Karman_vortex_street`

In this tutorial, we present the :math:`D_2Q_9` for Navier-Stokes equation to solve the Von Karman vortex street in 2D by using pylbm.

:download:`get the notebook<./notebooks/08_advection_reaction.ipynb>`


:doc:`./notebooks/08_advection_reaction`

In this tutorial, we will show how to implement with pylbm the :math:`D_1Q_2` for the advection equation with a source term.

